#!/bin/ksh

#**********************************************************************
#*-------------------------------------------------------------------------------
#* Licensed Materials - Property of IBM
#*
#* 5724-A18
#*
#* (c) Copyright IBM Corp. 2000, 2001, 2002
#*
#* US Government Users Restricted Rights - Use, duplication or
#* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*-------------------------------------------------------------------------------

#
# In WCSDIR/logs dir
#
LOGFILE=wcEARpermits.log

EDITION=""
WCVERSION="5"
WCRELEASE="4"

OS_NAME=`uname`
OS_VERSION=""

BUILD=""
BUILDDATE=""

WCSDIR=""
WASDIR=""
WASVERSION=4.0.2
WASBUILD=a0150.05
WASDATE=12/18/2001


##
## Begin of script function
##

DATE=`(/usr/bin/date)`


# Preset the WCS path by OS
if [[ "$OS_NAME" = "AIX" ]];
then

   WCSDIR=/usr/WebSphere/CommerceServer
   WASDIR=/usr/WebSphere/AppServer

   OS_VERSION=`oslevel`

   if [[ -f ${WCSDIR}/bin/build.txt ]];
   then
      BUILD=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk -v FS=";" '{print $2}' | /usr/bin/awk '{print $3}')`
      BUILDDATE=`( /usr/bin/echo $BUILD | /usr/bin/cut -d"d" -f1 )`
      EDITION=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk -v FS=";" '{print $3}' | /usr/bin/awk '{print $2}')`
   else
      /usr/bin/echo ""
      /usr/bin/echo "ERROR: ${WCSDIR}/bin/build.txt not found." | tee -a ${WCSDIR}/logs/${LOGFILE}
      /usr/bin/echo ""
      exit 1
   fi


elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]];
then

   WCSDIR=/opt/WebSphere/CommerceServer
   WASDIR=/opt/WebSphere/AppServer

   OS_VERSION=`uname -r`

   if [[ -f ${WCSDIR}/bin/build.txt ]];
   then
      BUILD=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk '{FS=";"}{print $2}' | /usr/bin/awk '{print $3}')`
      BUILDDATE=`( /usr/bin/echo $BUILD | /usr/bin/cut -d"d" -f1 )`
      EDITION=`( /usr/bin/cat ${WCSDIR}/bin/build.txt | /usr/bin/awk '{FS=";"}{print $3}' | /usr/bin/awk '{print $2}')`
   else
      /usr/bin/echo ""
      /usr/bin/echo "ERROR: ${WCSDIR}/bin/build.txt not found." | tee -a ${WCSDIR}/logs/${LOGFILE}
      /usr/bin/echo ""
      exit 1
   fi


else
   /usr/bin/echo "Unsupported platform: $OS_NAME" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "Exiting ..." | tee -a ${WCSDIR}/logs/${LOGFILE}
   exit 1
fi


if [[ -f ${WCSDIR}/logs/${LOGFILE} ]];
then
   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "Begin Modify EAR Permission Script Execution:${DATE}" | tee -a ${WCSDIR}/logs/${LOGFILE}
else
   /usr/bin/echo "" > ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "Begin Modify EAR Permission Script Execution:${DATE}" | tee -a ${WCSDIR}/logs/${LOGFILE}
fi


while :
do

   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "WEBSPHERE APPLICATION SERVER" | tee -a ${WCSDIR}/logs/${LOGFILE}

   read CHECK_DIR?"Enter the WAS HOME directory [Default:$WASDIR]:"

   if [[ "${CHECK_DIR}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   if [[ "${CHECK_DIR}" = "" ]];
   then
      /usr/bin/echo "Using Default of $WASDIR" | tee -a ${WCSDIR}/logs/${LOGFILE}
      CHECK_DIR=$WASDIR
   fi

   if [[ -d ${CHECK_DIR} ]];
   then
      WASDIR=$CHECK_DIR
      /usr/bin/echo "WAS HOME is $WASDIR" | tee -a ${WCSDIR}/logs/${LOGFILE}

      if [[ ! -f ${WASDIR}/properties/com/ibm/websphere/product.xml ]];
      then
         /usr/bin/echo "ERROR: No WAS product.xml detected. Invalid WAS HOME $WASDIR" | tee -a ${WCSDIR}/logs/${LOGFILE}
         continue
      fi

   else
      /usr/bin/echo "Invalid entry of $CHECK_DIR" | tee -a ${WCSDIR}/logs/${LOGFILE}
      continue
   fi

   break;
done

while :
do
   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "==================================" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "Confirmation of Information       " | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "==================================" | tee -a ${WCSDIR}/logs/${LOGFILE}

   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "EDITION=$EDITION" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "WASHOME=$WASDIR" | tee -a ${WCSDIR}/logs/${LOGFILE}

   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}

   #
   # For each instance present already
   #
   for INSTANCEDIRS in `(/usr/bin/ls -F $WCSDIR/instances | /usr/bin/grep "/" | /usr/bin/grep -v "^default/" | /usr/bin/cut -d"/" -f1)`;
   do
      #
      # For all dirs except default under instances, change the below
      #
      if [[ -d ${WASDIR}/installedApps/WC_Enterprise_App_${INSTANCEDIRS}.ear ]];
      then
         /usr/bin/echo "COMMERCE INSTANCE=${INSTANCEDIRS}" | tee -a ${WCSDIR}/logs/${LOGFILE}
      fi
   done

   /usr/bin/echo "" | tee -a ${WCSDIR}/logs/${LOGFILE}

   /usr/bin/echo "Confirm the above information is correct [Default:NONE]" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "1: YES - Information Above is Correct. Proceed to modify permissions" | tee -a ${WCSDIR}/logs/${LOGFILE}
   /usr/bin/echo "2: NO - Information Above is Incorrect. Exit" | tee -a ${WCSDIR}/logs/${LOGFILE}
   read TEMP?":"


   if [[ "${TEMP}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   VALID=`(/usr/bin/echo $TEMP | /usr/bin/grep "[0-9]")`
   if [[ $? -ne 0 ]];
   then
      /usr/bin/echo "Invalid entry $TEMP" | tee -a ${WCSDIR}/logs/${LOGFILE}
      continue
   fi

   if [[ $TEMP -eq 1 ]];
   then

      #
      # For each instance present already
      #
      for INSTANCEDIRS in `(/usr/bin/ls -F $WCSDIR/instances | /usr/bin/grep "/" | /usr/bin/grep -v "^default/" | /usr/bin/cut -d"/" -f1)`;
      do
         #
         # For all dirs except default under instances, change the below
         #
         if [[ -d ${WASDIR}/installedApps/WC_Enterprise_App_${INSTANCEDIRS}.ear ]];
         then
            /usr/bin/echo "Changing ${WASDIR}/installedApps/WC_Enterprise_App_${INSTANCEDIRS}.ear" | tee -a ${WCSDIR}/logs/${LOGFILE}
            /usr/bin/chmod -R 755 ${WASDIR}/installedApps/WC_Enterprise_App_${INSTANCEDIRS}.ear
         fi
      done

   elif [[ $TEMP -eq 2 ]];
   then
      /usr/bin/echo "Exiting ..." | tee -a ${WCSDIR}/logs/${LOGFILE}
   else
      /usr/bin/echo "Invalid entry" | tee -a ${WCSDIR}/logs/${LOGFILE}
      continue
   fi

   break;
done
